Date: 01 4, 2002 12:00:24 PM

# prrange

## Purpose

Print the text under a range of rule elements number1 to number2 to fileName.

## Syntax

prrange(fileName, number1, number2)

fileName - type: str
number1 - type: int
number2 - type: int

## Returns

## Remarks

The output file (fileName) must be set up in advance using openfile, fileout or an output statement.

## Example

@POST
@@POST

@RULES

@@RULES

## See Also

print, printr, prlit, openfile, fileout, POST Actions